const fs = require('fs')
const path = require('path')

const filePath = path.join(__dirname, '../data/data.json')

const ensureDataFileExists = () => {
    const dataDir = path.dirname(filePath);

    // Check if the directory exists, if not, create it
    if (!fs.existsSync(dataDir)) {
        fs.mkdirSync(dataDir, { recursive: true }); // Create the directory and any missing parent directories
    }

    // Check if the data file exists, if not, create an empty array as JSON
    if (!fs.existsSync(filePath)) {
        fs.writeFileSync(filePath, '[]', 'utf8'); // Initialize with an empty array
    }
};
const loadData = () => {
    ensureDataFileExists();

    try {
        const dataBuffer = fs.readFileSync(filePath);
        const dataString = dataBuffer.toString();

        // Check if file content is empty
        if (dataString.trim() === '') {
            return [];
        }

        return JSON.parse(dataString);
    } catch (error) {
        console.error('Error parsing JSON:', error);
        return []; // Return an empty array if JSON is invalid
    }
}

const saveData = (data) => {
    try {
        const jsonString = JSON.stringify(data, null, 2); // Convert data to JSON string
        fs.writeFileSync(filePath, jsonString); // Write the JSON to file
    } catch (error) {
        console.error('Error saving data:', error);
    }
};

module.exports = { loadData, saveData }